
# GCP Utils Package

**Includes the following Methods:**

 - def  upload_to_gcp_storage(bucket, src_filename, dest_filename, folder='')

		Function to upload a file to google cloud storage
		:parameter bucket: name of bucket to upload files to
		:parameter src_filename: name of source filename to upload
		:parameter dest_filename: specify name of file once uploaded
		:parameter folder: optional folder path to upload to. (e.g 'folder1/')

 - def  download_from_gcp_storage(bucket, src_filename, dest_filename, folder=''):

		Function to download a file to google cloud storage
		:parameter bucket: name of bucket to download files from
		:parameter src_filename: name of source filename to download
		:parameter dest_filename: specify name of file once downloaded
		:parameter folder: optional folder path to download from. (e.g 'folder1/')

 - def  list_gcp_bucket_blobs(bucket, prefixStr=''):

		Function to list bucket from google cloud storage
		:parameter bucket: name of bucket to grab items from
        :parameter prefixStr: optional prefix for files to list in bucket
		:return array: returns array of bucket items in blob format